@@ -6,6 +6,8 @@ import logging.config
 __version__ = _version()
 
 try:
-    logging.config.fileConfig(os.path.join(__home(), 'logging.ini'), disable_existing_loggers=False)
-except:
-    print("MoleculeKit: Logging setup failed")
\ No newline at end of file
+    logging.config.fileConfig(
+        os.path.join(__home(), "logging.ini"), disable_existing_loggers=False
+    )
+except Exception:
+    print("MoleculeKit: Logging setup failed")
