@@ -4,9 +4,9 @@
 # No redistribution in whole or part
 #
 import os
-import math
 import numpy as np
 from rdkit import Chem
+from rdkit.Chem import PandasTools
 from moleculekit.smallmol.smallmol import SmallMol
 import gzip
 import logging
@@ -17,39 +17,45 @@ logger = logging.getLogger(__name__)
 
 def smiReader(file, removeHs, fixHs, isgzip=False):
     from tqdm import tqdm
+
     if isgzip:
-        with gzip.open(file, 'rb') as f:
+        with gzip.open(file, "rb") as f:
             return smiReader(f, removeHs=removeHs, fixHs=fixHs, isgzip=False)
 
     if isinstance(file, str):
-        with open(file, 'r') as f:
+        with open(file, "r") as f:
             return smiReader(f, removeHs, fixHs)
 
     decode = False
     if isinstance(file, gzip.GzipFile):
         decode = True
-            
+
     lines = file.readlines()[1:]
     mols = []
     for i, line in enumerate(tqdm(lines)):
         if decode:
-            line = line.decode('utf-8')
+            line = line.decode("utf-8")
         smi, name = line.strip().split()
         try:
             mols.append(SmallMol(smi, removeHs=removeHs, fixHs=fixHs))
         except Exception as e:
-            logger.warning('Failed to load molecule with name {} with error {}. Skipping to next molecule.'.format(name, e))
+            logger.warning(
+                "Failed to load molecule with name {} with error {}. Skipping to next molecule.".format(
+                    name, e
+                )
+            )
     return mols
 
+
 def sdfReader(file, removeHs, fixHs, sanitize, isgzip=False):
     from tqdm import tqdm
     from moleculekit.util import tempname
 
     if isgzip:
-        with gzip.open(file, 'rb') as f:
+        with gzip.open(file, "rb") as f:
             # SDMolSupplier does not support file handles, need to write temp file
-            file = tempname(suffix='.sdf')
-            with open(file, 'wb') as fout:
+            file = tempname(suffix=".sdf")
+            with open(file, "wb") as fout:
                 fout.write(f.read())
 
     supplier = Chem.SDMolSupplier(file, removeHs=removeHs, sanitize=sanitize)
@@ -61,15 +67,20 @@ def sdfReader(file, removeHs, fixHs, sanitize, isgzip=False):
             continue
         try:
             mols.append(SmallMol(mol, removeHs=removeHs, fixHs=fixHs))
-        except:
-            if mol.HasProp('_Name'):
-                name = mol.GetProp('_Name')
+        except Exception:
+            if mol.HasProp("_Name"):
+                name = mol.GetProp("_Name")
             countfailed += 1
-            logger.warning('Failed to load molecule{}. Skipping to next molecule.'.format(' with name {}'.format(name)))
+            logger.warning(
+                "Failed to load molecule{}. Skipping to next molecule.".format(
+                    " with name {}".format(name)
+                )
+            )
     if countfailed:
-        logger.info('Failed to load {}/{} molecules'.format(countfailed, len(supplier)))
+        logger.info("Failed to load {}/{} molecules".format(countfailed, len(supplier)))
     return mols
 
+
 class SmallMolLib(object):
     """
     Class to manage ligands databases (sdf). Ligands are stored as moleculekit.smallmol.smallmol.SmallMol objects and
@@ -106,25 +117,32 @@ class SmallMolLib(object):
 
     """
 
-    def __init__(self, libfile=None, removeHs=False, fixHs=True, sanitize=True):  # , n_jobs=1
+    def __init__(
+        self, libfile=None, removeHs=False, fixHs=True, sanitize=True
+    ):  # , n_jobs=1
         if libfile is not None:
-            self._mols = self._loadLibrary(libfile, removeHs=removeHs, fixHs=fixHs, sanitize=sanitize, ext=None)
+            self._mols = self._loadLibrary(
+                libfile, removeHs=removeHs, fixHs=fixHs, sanitize=sanitize, ext=None
+            )
 
-
-    def _loadLibrary(self, libfile, removeHs=False, fixHs=True, sanitize=True, ext=None):
+    def _loadLibrary(
+        self, libfile, removeHs=False, fixHs=True, sanitize=True, ext=None
+    ):
         isgzip = False
-        if ext == None:
-            ext = os.path.splitext(libfile)[-1] 
-        if ext == '.gz':
+        if ext is None:
+            ext = os.path.splitext(libfile)[-1]
+        if ext == ".gz":
             isgzip = True
             ext = os.path.splitext(os.path.splitext(libfile)[-2])[-1]
 
-        if ext == '.sdf':
+        if ext == ".sdf":
             return sdfReader(libfile, removeHs, fixHs, sanitize, isgzip)
-        elif ext == '.smi':
+        elif ext == ".smi":
             return smiReader(libfile, removeHs, fixHs, isgzip)
         else:
-            raise RuntimeError('Invalid file extension {}. Could not read it.'.format(ext))
+            raise RuntimeError(
+                "Invalid file extension {}. Could not read it.".format(ext)
+            )
 
     @property
     def numMols(self):
@@ -178,7 +196,9 @@ class SmallMolLib(object):
         writer = SDWriter(sdf_name)
         if fields is not None:
             if not isinstance(fields, list):
-                raise TypeError("The fields argument {} should be a list".format(type(fields)))
+                raise TypeError(
+                    "The fields argument {} should be a list".format(type(fields))
+                )
             writer.SetProps(fields)
 
         for m in self._mols:
@@ -199,19 +219,19 @@ class SmallMolLib(object):
             The header of the smi file. If is None the smi filename will be used.
         """
 
-        smi_name = os.path.splitext(smi_name)[0] + '.smi'
+        smi_name = os.path.splitext(smi_name)[0] + ".smi"
 
-        f = open(smi_name, 'w')
+        f = open(smi_name, "w")
 
         if header is None:
             header = os.path.splitext(smi_name)[0]
 
-        f.write(header + '\n')
+        f.write(header + "\n")
 
         for n, sm in enumerate(self.getMols()):
             smi = sm.toSMILES(explicitHs=explicitHs)
             name = n if not names else sm.ligname
-            f.write(smi + ' {} \n'.format(name))
+            f.write(smi + " {} \n".format(name))
 
         f.close()
 
@@ -226,7 +246,6 @@ class SmallMolLib(object):
         """
         self._mols += smallLib._mols
 
-
     def appendSmallMol(self, smallmolecule, strictField=False, strictDirection=0):
         """
         Adds a new moleculekit.smallmol.smallmol.SmallMol object in the current SmallMolLib object
@@ -249,12 +268,16 @@ class SmallMolLib(object):
         """
 
         if not isinstance(ids, list):
-            raise TypeError('The argument ids {} is not valid. Should be list'.format(type(ids)))
+            raise TypeError(
+                "The argument ids {} is not valid. Should be list".format(type(ids))
+            )
         _oldNumMols = self.numMols
         self._mols = np.delete(self._mols, ids)
 
-        logger.warning("[num mols before deleting: {}]. The molecules {} were removed, now the number of "
-                       "molecules are {} ".format(_oldNumMols, ids, self.numMols))
+        logger.warning(
+            "[num mols before deleting: {}]. The molecules {} were removed, now the number of "
+            "molecules are {} ".format(_oldNumMols, ids, self.numMols)
+        )
 
     def toDataFrame(self, fields=None, molAsImage=True, sketch=True):
         """
@@ -274,16 +297,19 @@ class SmallMolLib(object):
         dataframe: pandas.DataFrame
             The pandas DataFrame
         """
-        from rdkit.Chem import PandasTools
         from rdkit.Chem.AllChem import Compute2DCoords
         import pandas as pd
         from copy import deepcopy
 
         if fields is not None:
             if not isinstance(fields, list):
-                raise TypeError('The argument fields passed {} should be a list '.format(type(fields)))
+                raise TypeError(
+                    "The argument fields passed {} should be a list ".format(
+                        type(fields)
+                    )
+                )
         else:
-            fields = ['ligname', '_mol'] if molAsImage else ['ligname']
+            fields = ["ligname", "_mol"] if molAsImage else ["ligname"]
 
         records = []
         indexes = []
@@ -292,13 +318,13 @@ class SmallMolLib(object):
             if sketch:
                 mm = deepcopy(m._mol)
                 Compute2DCoords(mm)
-                row['_mol'] = mm
+                row["_mol"] = mm
             records.append(row)
             indexes.append(i)
 
         df = pd.DataFrame(records, columns=fields, index=indexes)
         if molAsImage:
-            Chem.PandasTools.ChangeMoleculeRendering(df)
+            PandasTools.ChangeMoleculeRendering(df)
         return df
 
     def copy(self):
@@ -306,6 +332,7 @@ class SmallMolLib(object):
         Returns a copy of the SmallMolLib object
         """
         from copy import deepcopy
+
         return deepcopy(self)
 
     def __len__(self):
@@ -322,12 +349,25 @@ class SmallMolLib(object):
     def __str__(self):
         _mols = self._mols
 
-        return ('Stack of Small molecules.'
-                '\n\tContains {} Molecules.'
-                '\n\tSource file: "{}".').format(len(_mols), self._sdffile)
+        return (
+            "Stack of Small molecules."
+            "\n\tContains {} Molecules."
+            '\n\tSource file: "{}".'
+        ).format(len(_mols), self._sdffile)
 
-    def depict(self, ids=None, sketch=True, filename=None, ipython=False, optimize=False, optimizemode='std',
-               removeHs=True,  legends=None, highlightAtoms=None, mols_perrow=3):
+    def depict(
+        self,
+        ids=None,
+        sketch=True,
+        filename=None,
+        ipython=False,
+        optimize=False,
+        optimizemode="std",
+        removeHs=True,
+        legends=None,
+        highlightAtoms=None,
+        mols_perrow=3,
+    ):
 
         """
         Depicts the molecules into a grid. It is possible to save it into an svg file and also generates a
@@ -362,14 +402,21 @@ class SmallMolLib(object):
             ipython_svg: SVG object if ipython is set to True
 
         """
-        from rdkit.Chem.AllChem import Compute2DCoords, EmbedMolecule, MMFFOptimizeMolecule, ETKDG
+        from rdkit.Chem.AllChem import (
+            Compute2DCoords,
+            EmbedMolecule,
+            MMFFOptimizeMolecule,
+            ETKDG,
+        )
         from rdkit.Chem import RemoveHs
         from moleculekit.smallmol.util import depictMultipleMols
 
         if sketch and optimize:
-            raise ValueError('Impossible to use optmization in  2D sketch representation')
+            raise ValueError(
+                "Impossible to use optmization in  2D sketch representation"
+            )
 
-        if legends is not None and legends not in ['names', 'items']:
+        if legends is not None and legends not in ["names", "items"]:
             raise ValueError('The "legends" should be "names" or "items"')
 
         _smallmols = self.getMols(ids)
@@ -381,8 +428,10 @@ class SmallMolLib(object):
 
         if highlightAtoms is not None:
             if len(highlightAtoms) != len(_mols):
-                raise ValueError('The highlightAtoms {} should have the same length of the '
-                                 'mols {}'.format(len(highlightAtoms), len(_mols)))
+                raise ValueError(
+                    "The highlightAtoms {} should have the same length of the "
+                    "mols {}".format(len(highlightAtoms), len(_mols))
+                )
 
         if sketch:
             for _m in _mols:
@@ -393,28 +442,36 @@ class SmallMolLib(object):
 
         # activate 3D coords optimization
         if optimize:
-            if optimizemode == 'std':
+            if optimizemode == "std":
                 for _m in _mols:
                     EmbedMolecule(_m)
-            elif optimizemode == 'mmff':
+            elif optimizemode == "mmff":
                 for _m in _mols:
                     MMFFOptimizeMolecule(_m, ETKDG())
 
         legends_list = []
-        if legends == 'names':
-            legends_list = [_m.getProp('ligname') for _m in _smallmols]
-        elif legends == 'items':
-            legends_list = [str(n+1) for n in range(len(_smallmols))]
+        if legends == "names":
+            legends_list = [_m.getProp("ligname") for _m in _smallmols]
+        elif legends == "items":
+            legends_list = [str(n + 1) for n in range(len(_smallmols))]
+
+        return depictMultipleMols(
+            _mols,
+            ipython=ipython,
+            legends=legends_list,
+            highlightAtoms=highlightAtoms,
+            filename=filename,
+            mols_perrow=mols_perrow,
+        )
 
-        return depictMultipleMols(_mols, ipython=ipython, legends=legends_list, highlightAtoms=highlightAtoms,
-                                  filename=filename, mols_perrow=mols_perrow)
 
 SmallMolStack = SmallMolLib
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     import doctest
-    import os
     from moleculekit.home import home
 
-    lib = SmallMolLib(os.path.join(home(dataDir='test-smallmol'), 'fda_drugs_light.sdf'))
-    doctest.testmod(extraglobs={'lib': lib})
\ No newline at end of file
+    lib = SmallMolLib(
+        os.path.join(home(dataDir="test-smallmol"), "fda_drugs_light.sdf")
+    )
+    doctest.testmod(extraglobs={"lib": lib})
