@@ -4,4 +4,4 @@
 # No redistribution in whole or part
 #
 def version():
-    return '0.8.5'
\ No newline at end of file
+    return "0.9.0"
